# requires-regex [![NPM version](https://img.shields.io/npm/v/requires-regex.svg?style=flat)](https://www.npmjs.com/package/requires-regex) [![NPM monthly downloads](https://img.shields.io/npm/dm/requires-regex.svg?style=flat)](https://npmjs.org/package/requires-regex) [![NPM total downloads](https://img.shields.io/npm/dt/requires-regex.svg?style=flat)](https://npmjs.org/package/requires-regex) [![Linux Build Status](https://img.shields.io/travis/jonschlinkert/requires-regex.svg?style=flat&label=Travis)](https://travis-ci.org/jonschlinkert/requires-regex)

> Regular expression for matching javascript require statements.

Please consider following this project's author, [Jon Schlinkert](https://github.com/jonschlinkert), and consider starring the project to show your :heart: and support.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install --save requires-regex
```

## Usage

THe main export is a function that must be called. This ensures that a new regex is returned each time the function is called.

```js
const regex = require('requires-regex')();
const match = regex.exec('const foo = require(\'@bar/baz\');');

console.log(match);
// [ 'const foo = require(\'@bar/baz\');',
//   undefined,
//   'foo',
//   '\'',
//   '@bar/baz',
//   'bar',
//   'baz',
//   index: 0,
//   input: 'const foo = require(\'@bar/baz\');' ]
```

**Match results**

* `0` - the full match
* `1` - require statements inside quoted strings, otherwise undefined.
* `2` - variable name before `require()`, if defined, otherwise undefined
* `3` - leading quote inside `require()`, this is used as a reference to match ends on a trailing quote of the same type
* `4` - the full name inside the `require()` statement. For example, in `require("@foo/bar")`, the full name is `@foo/bar`.
* `5` - the first segment of a scoped name. For example, `foo` in `@foo/bar`. Otherwise undefined.
* `6` - the second segment of a scoped name. For example, `bar` in `@foo/bar`. Otherwise undefined.

## About

<details>
<summary><strong>Contributing</strong></summary>

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](../../issues/new).

</details>

<details>
<summary><strong>Running Tests</strong></summary>

Running and reviewing unit tests is a great way to get familiarized with a library and its API. You can install dependencies and run tests with the following command:

```sh
$ npm install && npm test
```

</details>

<details>
<summary><strong>Building docs</strong></summary>

_(This project's readme.md is generated by [verb](https://github.com/verbose/verb-generate-readme), please don't edit the readme directly. Any changes to the readme must be made in the [.verb.md](.verb.md) readme template.)_

To generate the readme, run the following command:

```sh
$ npm install -g verbose/verb#dev verb-generate-readme && verb
```

</details>

### Related projects

You might also be interested in these projects:

* [lint-deps](https://www.npmjs.com/package/lint-deps): CLI tool that tells you when dependencies are missing from package.json and offers you a… [more](https://github.com/jonschlinkert/lint-deps) | [homepage](https://github.com/jonschlinkert/lint-deps "CLI tool that tells you when dependencies are missing from package.json and offers you a choice to install them. Also tells you when dependencies are listed in package.json but are not being used anywhere in your project. Node.js command line tool and API")
* [match-requires](https://www.npmjs.com/package/match-requires): Match require statements in a string. Returns an array of matching require statements. Each match… [more](https://github.com/jonschlinkert/match-requires) | [homepage](https://github.com/jonschlinkert/match-requires "Match require statements in a string. Returns an array of matching require statements. Each match is an object with line number, variable name, and module name. Statements in code comments are ignored.")
* [regex-cache](https://www.npmjs.com/package/regex-cache): Memoize the results of a call to the RegExp constructor, avoiding repetitious runtime compilation of… [more](https://github.com/jonschlinkert/regex-cache) | [homepage](https://github.com/jonschlinkert/regex-cache "Memoize the results of a call to the RegExp constructor, avoiding repetitious runtime compilation of the same string and options, resulting in surprising performance improvements.")

### Contributors

| **Commits** | **Contributor** | 
| --- | --- |
| 22 | [jonschlinkert](https://github.com/jonschlinkert) |
| 1 | [alvinsight](https://github.com/alvinsight) |

### Author

**Jon Schlinkert**

* [LinkedIn Profile](https://linkedin.com/in/jonschlinkert)
* [GitHub Profile](https://github.com/jonschlinkert)
* [Twitter Profile](https://twitter.com/jonschlinkert)

### License

Copyright © 2018, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT License](LICENSE).

***

_This file was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme), v0.6.0, on April 15, 2018._